@@ -364,7 +364,7 @@ editor_show_grid_settings_dialog (GtkWidget *widget)
 		    GTK_EXPAND | GTK_FILL, 0, 5, 5);
   gtk_widget_show (button);
   gtk_object_set_data (GTK_OBJECT (dialog), "button1", button);
-  group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+  group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (button));
 
   button = gtk_radio_button_new_with_label (group, _("Lines"));
   if (editor_grid_style == GB_GRID_LINES)
@@ -2893,11 +2893,21 @@ editor_on_key_press_event (GtkWidget * widget, GdkEventKey * event,
       break;
     }
 
+#if 0
   /* We don't want modifier keys to be redirected, since trying to use an
      accelerator, e.g. Ctrl-X to cut the widget, would clear the label. */
   if (!handled
       && !(event->state & GDK_CONTROL_MASK)
       && key != GDK_Caps_Lock
+      && key != GDK_Tab && key != GDK_KP_Tab
+      && key != GDK_Left && key != GDK_KP_Left
+      && key != GDK_Right && key != GDK_KP_Right
+      && key != GDK_Up && key != GDK_KP_Up
+      && key != GDK_Down && key != GDK_KP_Down
+      && key != GDK_Page_Up && key != GDK_KP_Page_Up
+      && key != GDK_Page_Down && key != GDK_KP_Page_Down
+      && key != GDK_Home && key != GDK_KP_Home
+      && key != GDK_End && key != GDK_KP_End
       && key != GDK_Control_L && key != GDK_Control_R
       && key != GDK_Shift_L && key != GDK_Shift_R
       && key != GDK_Meta_L && key != GDK_Meta_R
@@ -2920,6 +2930,7 @@ editor_on_key_press_event (GtkWidget * widget, GdkEventKey * event,
 	  handled = TRUE;
 	}
     }
+#endif
 
   if (handled)
     {
