@@ -157,7 +157,7 @@ gb_label_create_standard_properties (GtkWidget * widget,
 		      _("The widget to set the keyboard focus to when the underlined accelerator key is used"),
 		      NULL);
   combo = property_get_value_widget (focus_target_p);
-  gtk_entry_set_editable (GTK_ENTRY (GTK_COMBO (combo)->entry), FALSE);
+  gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (combo)->entry), FALSE);
   gtk_combo_set_value_in_list (GTK_COMBO (combo), TRUE, TRUE);
 }
 
