@@ -40,9 +40,14 @@ static gchar *ShowTabs = "GtkNotebook::show_tabs";
 static gchar *ShowBorder = "GtkNotebook::show_border";
 static gchar *TabPos = "GtkNotebook::tab_pos";
 static gchar *Scrollable = "GtkNotebook::scrollable";
+static gchar *Popups = "GtkNotebook::enable_popup";
+
+#if 0
+/* These seem to be deprecated. */
 static gchar *TabHBorder = "GtkNotebook::tab_hborder";
 static gchar *TabVBorder = "GtkNotebook::tab_vborder";
-static gchar *Popups = "GtkNotebook::enable_popup";
+#endif
+
 /* This isn't save in the XML as it is implicit. */
 static gchar *NumPages = "GtkNotebook::num_pages";
 
@@ -274,12 +279,15 @@ gb_notebook_create_properties (GtkWidget * widget, GbWidgetCreateArgData * data)
 		       GbTabPosChoices);
   property_add_bool (Scrollable, _("Scrollable:"),
 		     _("If the notebook tabs are scrollable"));
+#if 0
+/* These seem to be deprecated. */
   property_add_int_range (TabHBorder, _("Tab Horz. Border:"),
 			  _("The size of the notebook tabs' horizontal border"),
 			  0, 1000, 1, 10, 1);
   property_add_int_range (TabVBorder, _("Tab Vert. Border:"),
 			  _("The size of the notebook tabs' vertical border"),
 			  0, 1000, 1, 10, 1);
+#endif
   property_add_bool (Popups, _("Show Popup:"), _("If the popup menu is enabled"));
   property_add_int_range (NumPages, _("Number of Pages:"),
 		          _("The number of notebook pages"),
@@ -308,8 +316,13 @@ gb_notebook_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
     }
 
   gb_widget_output_bool (data, Scrollable, GTK_NOTEBOOK (widget)->scrollable);
+
+#if 0
+/* These seem to be deprecated. */
   gb_widget_output_int (data, TabHBorder, GTK_NOTEBOOK (widget)->tab_hborder);
   gb_widget_output_int (data, TabVBorder, GTK_NOTEBOOK (widget)->tab_vborder);
+#endif
+
   gb_widget_output_bool (data, Popups,
 			 (GTK_NOTEBOOK (widget)->menu) ? TRUE : FALSE);
 
@@ -361,6 +374,8 @@ gb_notebook_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
   if (data->apply)
     gtk_notebook_set_scrollable (GTK_NOTEBOOK (widget), scrollable);
 
+#if 0
+/* These seem to be deprecated. */
   tab_border = gb_widget_input_int (data, TabHBorder);
   if (data->apply)
     gtk_notebook_set_tab_hborder (GTK_NOTEBOOK (widget), tab_border);
@@ -368,6 +383,7 @@ gb_notebook_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
   tab_border = gb_widget_input_int (data, TabVBorder);
   if (data->apply)
     gtk_notebook_set_tab_vborder (GTK_NOTEBOOK (widget), tab_border);
+#endif
 
   popups = gb_widget_input_bool (data, Popups);
   if (data->apply)
@@ -624,6 +640,8 @@ gb_notebook_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 		"  gtk_notebook_set_scrollable (GTK_NOTEBOOK (%s), TRUE);\n",
 		data->wname);
 
+#if 0
+/* These seem to be deprecated. */
   if (GTK_NOTEBOOK (widget)->tab_hborder != 2)
     source_add (data,
 		"  gtk_notebook_set_tab_hborder (GTK_NOTEBOOK (%s), %i);\n",
@@ -632,6 +650,8 @@ gb_notebook_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
     source_add (data,
 		"  gtk_notebook_set_tab_vborder (GTK_NOTEBOOK (%s), %i);\n",
 		data->wname, GTK_NOTEBOOK (widget)->tab_vborder);
+#endif
+
   if (GTK_NOTEBOOK (widget)->menu)
     source_add (data,
 		"  gtk_notebook_popup_enable (GTK_NOTEBOOK (%s));\n",
