@@ -78,7 +78,7 @@ find_parents_group (GtkWidget * widget, GSList ** group)
     return;
 
   if (GTK_IS_RADIO_BUTTON (widget))
-    *group = gtk_radio_button_group (GTK_RADIO_BUTTON (widget));
+    *group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
 }
 
 
@@ -151,7 +151,7 @@ gb_radio_button_create_properties (GtkWidget * widget, GbWidgetCreateArgData *
 		      _("The radio button group (the default is all radio buttons with the same parent)"),
 		      NULL);
   combo = property_get_value_widget (Group);
-  gtk_entry_set_editable (GTK_ENTRY (GTK_COMBO (combo)->entry), FALSE);
+  gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (combo)->entry), FALSE);
 }
 
 
@@ -356,7 +356,7 @@ gb_radio_button_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
     {
       GSList *old_group, *new_group = NULL;
 
-      old_group = gtk_radio_button_group (GTK_RADIO_BUTTON (widget));
+      old_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
 
       if (group_name && (group_name[0] == '\0'
 			 || !strcmp (group_name, _("New Group"))))
@@ -374,7 +374,7 @@ gb_radio_button_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 	  find_group_widget (component, &find_data);
 
 	  if (find_data.found_widget)
-	    new_group = gtk_radio_button_group (GTK_RADIO_BUTTON (find_data.found_widget));
+	    new_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (find_data.found_widget));
 	}
 
 #if 0
@@ -428,7 +428,7 @@ gb_radio_button_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data
 	      "  gtk_radio_button_set_group (GTK_RADIO_BUTTON (%s), %s_group);\n",
 	      data->wname, group_name);
   source_add (data,
-	      "  %s_group = gtk_radio_button_group (GTK_RADIO_BUTTON (%s));\n",
+	      "  %s_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (%s));\n",
 	      group_name, data->wname);
   g_free (group_name);
 
