@@ -118,6 +118,8 @@ glade_clipboard_init (GladeClipboard * clipboard)
   gtk_window_set_policy (GTK_WINDOW (clipboard), FALSE, TRUE, FALSE);
   gtk_window_set_wmclass (GTK_WINDOW (clipboard), "clipboard", "Glade");
   gtk_window_set_default_size (GTK_WINDOW (clipboard), 150, 200);
+  gtk_window_add_accel_group (GTK_WINDOW (clipboard),
+			      glade_get_global_accel_group ());
 
   vbox = gtk_vbox_new (FALSE, 4);
   gtk_widget_show (vbox);
