@@ -44,9 +44,12 @@ GladeProject *current_project = NULL;
 
 
 /* The order must match the GladeLanguageType enum in glade_project.h. */
-gchar *GladeLanguages[] = { "C", "C++", "Ada 95", "Perl", "Eiffel" };
+gchar *GladeLanguages[] = { "C", "C++" , "Ada 95", "Perl", "Eiffel" };
+#if 1
+gint GladeNumLanguages = 2; /* Only C and C++ for now. */
+#else
 gint GladeNumLanguages = sizeof (GladeLanguages) / sizeof (GladeLanguages[0]);
-
+#endif
 
 static void glade_project_class_init (GladeProjectClass * klass);
 static void glade_project_init (GladeProject *project);
@@ -456,7 +459,8 @@ glade_project_write_cxx_source (GladeProject *project)
     {
       return glade_error_new_general (GLADE_STATUS_ERROR,
 				      _("Error running glade-- to generate the C++ source code.\n"
-					"Check that you have glade-- installed and that it is in your PATH."));
+					"Check that you have glade-- installed and that it is in your PATH.\n"
+					"Then try running 'glade-- <project_file.glade>' in a terminal."));
     }
 
   return NULL;
@@ -784,6 +788,8 @@ glade_project_foreach_component		(GladeProject  *project,
 {
   GList *tmp_list;
 
+  g_return_if_fail (project != NULL);
+
   tmp_list = project->components;
   while (tmp_list)
     {
@@ -819,8 +825,9 @@ glade_project_add_pixmap		(GladeProject  *project,
 {
   if (filename && filename[0])
     {
+#if 0
       g_print ("Adding pixmap: %s\n", filename);
-
+#endif
       project->pixmap_filenames = g_list_prepend (project->pixmap_filenames,
 						  g_strdup (filename));
       glade_project_set_changed (project, TRUE);
@@ -839,7 +846,9 @@ glade_project_remove_pixmap		(GladeProject  *project,
   if (!filename)
     return;
 
+#if 0
   g_print ("Removing pixmap: %s\n", filename);
+#endif
 
   element = project->pixmap_filenames;
   while (element)
