@@ -183,7 +183,7 @@ struct _GladeProjectClass
 extern GladeProject *current_project;
 
 
-guint       glade_project_get_type		(void);
+GType       glade_project_get_type		(void);
 GladeProject*   glade_project_new		(void);
 
 /* Note that even if this command succeeds, there may be some error messages
