@@ -391,7 +391,7 @@ glade_project_options_init (GladeProjectOptions * options)
 						      GladeLanguages[language]);
       gtk_widget_show (radio_button);
       gtk_box_pack_start (GTK_BOX (hbox), radio_button, FALSE, TRUE, 4);
-      group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_button));
+      group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio_button));
 
       options->language_buttons[language] = radio_button;
     }
@@ -718,7 +718,7 @@ glade_project_options_init (GladeProjectOptions * options)
   gtk_widget_show (hbbox);
   gtk_box_pack_start (GTK_BOX (main_vbox), hbbox, TRUE, TRUE, 0);
   gtk_button_box_set_layout (GTK_BUTTON_BOX (hbbox), GTK_BUTTONBOX_END);
-  gtk_button_box_set_spacing (GTK_BUTTON_BOX (hbbox), 8);
+  gtk_box_set_spacing (GTK_BOX (hbbox), 8);
 
   options->cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
   GTK_WIDGET_SET_FLAGS (options->cancel_button, GTK_CAN_DEFAULT);
