@@ -342,14 +342,11 @@ static GnomeUIInfo MainMenu[] =
 
 static GnomeUIInfo ToolBar[] =
 {
-  /* I've taken this out to try to make the window smaller. */
-  /*
   {
     GNOME_APP_UI_ITEM, N_("New"), N_("New Project"), 
     glade_project_window_new_project, NULL, NULL,
     GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_NEW, 0, 0, NULL
   },
-  */
   {
     GNOME_APP_UI_ITEM, N_("Open"), N_("Open Project"), 
     glade_project_window_on_open_project, NULL, NULL,
@@ -366,7 +363,6 @@ static GnomeUIInfo ToolBar[] =
     glade_project_window_on_edit_options, NULL, NULL,
     GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PROPERTIES, 0, 0, NULL
   },
-  GNOMEUIINFO_SEPARATOR,
   {
     GNOME_APP_UI_ITEM, N_("Build"), N_("Build the Source Code"), 
     glade_project_window_write_source, NULL, NULL,
@@ -393,12 +389,12 @@ glade_project_window_new (void)
   gtk_window_set_wmclass (GTK_WINDOW (project_window->window),
 			  "project", "Glade");
 
-#ifdef FIXME
-  /* We want all the keyboard accelerators from the menus in the default
-     accel_group (or they won't work within the interface windows), so we
-     change the app's accel_group. This is a slight kludge. */
-  GNOME_APP (project_window->window)->accel_group = gtk_accel_group_get_default ();
-#endif
+  /* We want all the keyboard accelerators from the menus to work anywhere in
+     the Glade GUI, including windows being designed. So we add the accel
+     group to every window. */
+  GNOME_APP (project_window->window)->accel_group = glade_get_global_accel_group ();
+  gtk_window_add_accel_group (GTK_WINDOW (project_window->window),
+			      glade_get_global_accel_group ());
 
   /* Save a pointer to the GladeProjectWindow, so we can find it in callbacks.
    */
@@ -568,7 +564,7 @@ glade_project_window_new (void)
   gtk_widget_show (vbox_main);
 
   /* Create accelerator table */
-  accel_group = gtk_accel_group_new ();
+  accel_group = glade_get_global_accel_group ();
   gtk_window_add_accel_group (GTK_WINDOW (project_window->window),
 			      accel_group);
 
@@ -592,7 +588,7 @@ glade_project_window_new (void)
 
   /* create File menu */
   menuitem = gtk_menu_item_new_with_mnemonic (_("_Project"));
-  gtk_menu_bar_append (GTK_MENU_BAR (menubar), menuitem);
+  gtk_container_add (GTK_CONTAINER (menubar), menuitem);
   gtk_widget_show (menuitem);
 
   menu = gtk_menu_new ();
@@ -658,7 +654,7 @@ glade_project_window_new (void)
 
   /* Create Edit menu */
   menuitem = gtk_menu_item_new_with_mnemonic (_("_Edit"));
-  gtk_menu_bar_append (GTK_MENU_BAR (menubar), menuitem);
+  gtk_container_add (GTK_CONTAINER (menubar), menuitem);
   gtk_widget_show (menuitem);
 
   menu = gtk_menu_new ();
@@ -687,7 +683,7 @@ glade_project_window_new (void)
 
   /* Create View menu */
   menuitem = gtk_menu_item_new_with_mnemonic (_("_View"));
-  gtk_menu_bar_append (GTK_MENU_BAR (menubar), menuitem);
+  gtk_container_add (GTK_CONTAINER (menubar), menuitem);
   gtk_widget_show (menuitem);
 
   menu = gtk_menu_new ();
@@ -792,7 +788,7 @@ glade_project_window_new (void)
 
   /* Create Help menu */
   menuitem = gtk_menu_item_new_with_mnemonic (_("_Help"));
-  gtk_menu_bar_append (GTK_MENU_BAR (menubar), menuitem);
+  gtk_container_add (GTK_CONTAINER (menubar), menuitem);
   gtk_widget_show (menuitem);
 
   menu = gtk_menu_new ();
@@ -1027,7 +1023,7 @@ glade_project_window_on_new_project_ok (GladeProjectWindow *project_window)
 		      _("New project created."));
 
   /* Make sure the palette is sensitive now. */
-  gtk_widget_set_sensitive (glade_palette, TRUE);
+  gtk_widget_set_sensitive (GTK_BIN (glade_palette)->child, TRUE);
 }
 
 
@@ -1102,7 +1098,7 @@ glade_project_window_open_project (GladeProjectWindow *project_window,
       gtk_statusbar_push (GTK_STATUSBAR (project_window->statusbar), 1,
 			  _("Project opened."));
       /* Make sure the palette is sensitive now. */
-      gtk_widget_set_sensitive (glade_palette, TRUE);
+      gtk_widget_set_sensitive (GTK_BIN (glade_palette)->child, TRUE);
     }
   else
     {
@@ -1111,7 +1107,7 @@ glade_project_window_open_project (GladeProjectWindow *project_window,
 	 create a new empty GTK+ project. */
 #ifdef USE_GNOME
       project = NULL;
-      gtk_widget_set_sensitive (glade_palette, FALSE);
+      gtk_widget_set_sensitive (GTK_BIN (glade_palette)->child, FALSE);
 #else
       project = glade_project_new ();
 #endif
@@ -1761,7 +1757,7 @@ glade_project_window_about (GtkWidget *widget,
   /* VERSION comes from configure.in - the only place it should be defined */
 
 #ifdef USE_GNOME
-  const gchar *author[] = { "Damon Chaplin <damon@ximian.com>",
+  const gchar *author[] = { "Damon Chaplin <damon@gnome.org>",
 			    "Martijn van Beers <martijn@earthling.net>",
 			    "Jacob Berkman <jacob@ximian.com>",
 			    NULL };
