@@ -190,7 +190,7 @@ static void
 gb_gnome_message_box_get_properties (GtkWidget *widget, GbWidgetGetArgData * data)
 {
   GtkWidget *pixmap, *label;
-  gchar *label_text;
+  const gchar *label_text;
   gint type_index;
 
   get_message_box_widgets (widget, &pixmap, &label);
@@ -202,7 +202,7 @@ gb_gnome_message_box_get_properties (GtkWidget *widget, GbWidgetGetArgData * dat
   gb_widget_output_choice (data, MessageBoxType, type_index,
 			   GbMessageBoxTypeSymbols[type_index]);
 
-  gtk_label_get (GTK_LABEL (label), &label_text);
+  label_text = gtk_label_get_text (GTK_LABEL (label));
   gb_widget_output_translatable_text (data, Message, label_text);
 
   gb_window_get_standard_properties (widget, data,
@@ -356,7 +356,7 @@ static void
 gb_gnome_message_box_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 {
   GtkWidget *pixmap, *label;
-  gchar *label_text;
+  const gchar *label_text;
   gint type_index;
   gchar *wname, *child_name;
 
@@ -366,7 +366,7 @@ gb_gnome_message_box_write_source (GtkWidget * widget, GbWidgetWriteSourceData *
 
   type_index = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget),
 						     MessageBoxType));
-  gtk_label_get (GTK_LABEL (label), &label_text);
+  label_text = gtk_label_get_text (GTK_LABEL (label));
 
   if (data->create_widget)
     {
