@@ -21,6 +21,9 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 #include <gtk/gtkmain.h>
 #include <gtk/gtkrc.h>
@@ -274,8 +277,9 @@ static guint
 final_setup_from_main_loop (gpointer data)
 {
   GladeProjectWindow *project_window;
-  gchar *directory;
+  gchar *directory, *pathname = NULL;
   gchar *session_file = NULL;
+  gboolean loaded_file = FALSE;
 
   project_window = glade_project_window_new ();
   gtk_widget_show (project_window->window);
@@ -289,37 +293,61 @@ final_setup_from_main_loop (gpointer data)
   if (arg_show_clipboard)
     glade_show_clipboard ();
 
+   if (arg_filename)
+    {
+      directory = g_get_current_dir ();
+      pathname = glade_util_make_absolute_path (directory, arg_filename);
+      g_free (directory);
+    }
+
   /* First we check for a saved session, else we check for a normal project
      file on the command-line. */
 #ifdef USE_GNOME
   session_file = get_session_file (GladeClient);
   if (g_file_test (session_file, G_FILE_TEST_EXISTS))
     {
-      /* Note that arg_filename may be NULL, if the project hasn't been
-	 saved yet. */
-      GladeSessionFile = session_file;
-      glade_project_window_open_project (project_window, arg_filename);
-      GladeSessionFile = NULL;
+      struct stat pathname_stat, session_file_stat;
+      int status1 = -1, status2 = -1;
+
+      /* Note that pathname may be NULL, if the project hasn't been
+	 saved yet. NOTE: This could cause problems if the user explicitly
+	 saves a session without saving the Glade project, and then keeps
+	 using that session on startup. Glade will always think the project
+	 is a new one, even if the user saves it at some point. (Sessions
+	 shouldn't be used this way really.) */
+      if (pathname)
+	{
+	  status1 = stat (pathname, &pathname_stat);
+	  status2 = stat (session_file, &session_file_stat);
+	}
+
+      /* We only want to load the session file if it is newer than the
+	 real project XML file. i.e. its mtime is greater. */
+      if (status1 == -1 || status2 == -1
+	  || session_file_stat.st_mtime >= pathname_stat.st_mtime)
+	{
+	  GladeSessionFile = session_file;
+	  glade_project_window_open_project (project_window, pathname);
+	  GladeSessionFile = NULL;
+	  loaded_file = TRUE;
+	}
     }
-  else
+  g_free (session_file);
 #endif
-   if (arg_filename)
+
+   if (!loaded_file && pathname)
     {
-      directory = g_get_current_dir ();
-      arg_filename = glade_util_make_absolute_path (directory, arg_filename);
-      glade_project_window_open_project (project_window, arg_filename);
-      g_free (directory);
-      g_free (arg_filename);
+      glade_project_window_open_project (project_window, pathname);
     }
 
-  g_free (session_file);
+  g_free (pathname);
 
   /* For GNOME, we start with no current project, as the user needs to select
      between GTK+ and GNOME when creating a project. For GTK+ we can just
      create a GTK+ project. */
 #ifdef USE_GNOME
   if (current_project == NULL)
-    gtk_widget_set_sensitive (glade_palette, FALSE);
+    gtk_widget_set_sensitive (GTK_BIN (glade_palette)->child, FALSE);
 #else
   if (current_project == NULL)
     glade_project_new ();
