@@ -35,6 +35,19 @@
 #include "save.h"
 #include "utils.h"
 
+/* This is set if we are saving a session. A bit of a hack. */
+char *GladeSessionFile = NULL;
+
+
+/* The stuff to output at the start of XML files. */
+static gchar *GLADE_XML_BEGIN =
+	"<?xml version=\"1.0\" standalone=\"no\"?> <!--*- mode: xml -*-->\n"
+	"<!DOCTYPE glade-interface SYSTEM \"http://glade.gnome.org/glade-2.0.dtd\">\n\n";
+
+static gchar *GLADE_PROJECT_XML_BEGIN =
+	"<?xml version=\"1.0\" standalone=\"no\"?> <!--*- mode: xml -*-->\n"
+	"<!DOCTYPE glade-project SYSTEM \"http://glade.gnome.org/glade-project-2.0.dtd\">\n\n";
+
 
 /* An internal struct to pass data to the save_component() and
    save_named_style_callback() callbacks. */
@@ -45,8 +58,22 @@ struct _GladeSaveCallbackData
   FILE *fp;
 };
 
-static GladeError* save_project_file_internal (GladeProject *project);
+/* An internal struct to pass data to the save_requires_tags_cb(). */
+typedef struct _GladeSaveRequiresData GladeSaveRequiresData;
+struct _GladeSaveRequiresData
+{
+  /* We only support these 4 libs so we just have flags for each of them. */
+  gboolean require_gnome;
+  gboolean require_gnome_canvas;
+  gboolean require_gnomedb;
+  gboolean require_bonobo;
+};
 
+
+static GladeError* save_project_file_internal (GladeProject *project);
+static GladeError* save_xml_file_internal (GladeProject *project);
+
+static void save_requires_tags (FILE *fp, GladeProject *project);
 static void save_component (GtkWidget * item,
 			    GladeSaveCallbackData * save_data);
 
@@ -60,15 +87,9 @@ static void save_named_style (const gchar * name,
 			      FILE *fp);
 #endif
 
-static void save_buffer_add_string (GString * buffer,
-				    const gchar * string);
 static void save_buffer_flush (GbWidgetGetArgData * data,
 			       FILE *fp);
 
-static void save_indent (GbWidgetGetArgData * data);
-
-static void save_add_translatable_string (GbWidgetGetArgData * data,
-					  const gchar * string);
 static void save_translatable_strings (GbWidgetGetArgData * data);
 
 
@@ -83,24 +104,102 @@ save_project_file (GladeProject *project)
   old_locale = setlocale (LC_NUMERIC, NULL);
   saved_locale = g_strdup (old_locale);
   setlocale (LC_NUMERIC, "C");
+
   error = save_project_file_internal (project);
+
+  if (!error)
+    error = save_xml_file_internal (project);
+
   setlocale (LC_NUMERIC, saved_locale);
   g_free (saved_locale);
   return error;
 }
 
 
+/* Backup the file, to <filename>.bak, if it exists. */
+static GladeError*
+backup_file (const gchar *filename)
+{
+  gchar *backup_filename;
+  GladeError *error = NULL;
+  int status;
+
+  if (!glade_util_file_exists (filename))
+    return NULL;
+
+  backup_filename = g_strdup_printf ("%s.bak", filename);
+#if defined (__EMX__) || defined (_WIN32)
+  /* for OS/2 rename dosn't work if the dest. file exist ! remove it! */
+  status = remove (backup_filename);
+#endif
+  status = rename (filename, backup_filename);
+
+  if (status == -1)
+    {
+      error = glade_error_new_system (_("Couldn't rename file:\n  %s\nto:\n  %s\n"), filename, backup_filename);
+    }
+
+  g_free (backup_filename);
+  return error;
+}
+
+
 /* The main function to output the XML. It creates and initializes the
    GbWidgetGetArgData, opens the file, outputs the project options, the
    named styles, and then each component (window/dialog) in the interface. */
 static GladeError*
 save_project_file_internal (GladeProject *project)
 {
-  GbWidgetGetArgData data;
+  gchar *xml_filename, *filename;
+  GladeError *error;
+  FILE *fp;
+
+  if (GladeSessionFile)
+    xml_filename = GladeSessionFile;
+  else
+    xml_filename = glade_project_get_xml_filename (project);
+
+  filename = g_strdup_printf ("%sp", xml_filename);
+
+  if (!GladeSessionFile)
+    {
+      error = backup_file (filename);
+      if (error)
+	goto out;
+    }
+
+  fp = fopen (filename, "w");
+  if (fp == NULL)
+    {
+      error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
+				      filename);
+      goto out;
+    }
+
+  fprintf (fp, "%s", GLADE_PROJECT_XML_BEGIN);
+
+  error = glade_project_save_options (project, fp);
+
+  fclose (fp);
+
+ out:
+
+  g_free (filename);
+
+  return error;
+}
+
+
+/* The main function to output the XML. It creates and initializes the
+   GbWidgetGetArgData, opens the file, outputs the project options, the
+   named styles, and then each component (window/dialog) in the interface. */
+static GladeError*
+save_xml_file_internal (GladeProject *project)
+{
+  GbWidgetGetArgData data = { 0 };
   GladeSaveCallbackData save_data;
-  gchar *filename, *backup_filename;
+  gchar *filename;
   FILE *fp;
-  int status;
 
   MSG ("Saving project");
 
@@ -109,25 +208,16 @@ save_project_file_internal (GladeProject *project)
   data.copying_to_clipboard = FALSE;
   data.error = NULL;
 
-  filename = glade_project_get_xml_filename (project);
+  if (GladeSessionFile)
+    filename = GladeSessionFile;
+  else
+    filename = glade_project_get_xml_filename (project);
 
-  /* Backup the file, if it already exists. */
-  if (glade_util_file_exists (filename))
+  if (!GladeSessionFile)
     {
-      backup_filename = g_strdup_printf ("%s.bak", filename);
-#if defined (__EMX__) || defined (_WIN32)
-      /* for OS/2 rename dosn't work if the dest. file exist ! remove it! */
-      status = remove (backup_filename);
-#endif
-      status = rename (filename, backup_filename);
-
-      if (status == -1)
-	{
-	  data.error = glade_error_new_system (_("Couldn't rename file:\n  %s\nto:\n  %s\n"), filename, backup_filename);
-	  g_free (backup_filename);
-	  return data.error;
-	}
-      g_free (backup_filename);
+      data.error = backup_file (filename);
+      if (data.error)
+	return data.error;
     }
 
   fp = fopen (filename, "w");
@@ -140,17 +230,21 @@ save_project_file_internal (GladeProject *project)
   data.indent = 0;
 
   /* See if we need the translatable strings file output. */
-  data.save_translatable_strings = glade_project_get_output_translatable_strings (data.project);
+  data.save_translatable_strings = FALSE;
   data.translatable_strings = NULL;
-  if (data.save_translatable_strings)
-    data.translatable_strings = g_string_sized_new (1024);
+  if (!GladeSessionFile)
+    {
+      data.save_translatable_strings = glade_project_get_output_translatable_strings (data.project);
+      if (data.save_translatable_strings)
+	data.translatable_strings = g_string_sized_new (1024);
+    }
 
-  /* Output the XML version info and our root element '<GTK-Interface>'. */
-  fprintf (fp, "<?xml version=\"1.0\"?>\n<GTK-Interface>\n\n");
+  /* Output the XML version info and our root element '<glade-interface>'. */
+  fprintf (fp, "%s", GLADE_XML_BEGIN);
+  fprintf (fp, "<glade-interface>\n");
 
-  /* Save the general project information. */
-  glade_project_save_options (data.project, &data);
-  save_buffer_flush (&data, fp);
+  /* Output the requires tags. */
+  save_requires_tags (fp, project);
 
   /* Set up the struct to pass data to the callbacks. */
   save_data.data = &data;
@@ -180,7 +274,7 @@ save_project_file_internal (GladeProject *project)
   /* Finish the root element. */
   if (!data.error)
     {
-      fprintf (fp, "\n</GTK-Interface>\n");
+      fprintf (fp, "\n</glade-interface>\n");
     }
 
   /* Save the translatable strings file, if needed. */
@@ -201,6 +295,60 @@ save_project_file_internal (GladeProject *project)
 }
 
 
+static void
+save_requires_tags_cb (GtkWidget *widget,
+		       GladeSaveRequiresData * requires_data)
+{
+  const char *type_name;
+
+  type_name = g_type_name (G_OBJECT_TYPE (widget));
+
+  /* We assume that any classes starting with GnomeDB require the GnomeDB
+     support etc. Note that GNOME apps will probably require Bonobo for the
+     BonoboDock widgets used in GnomeApp. */
+  if (!strncmp (type_name, "GnomeDb", 7))
+    requires_data->require_gnomedb = TRUE;
+  else if (!strncmp (type_name, "GnomeCanvas", 11))
+    requires_data->require_gnome_canvas = TRUE;
+  else if (!strncmp (type_name, "Gnome", 5))
+    requires_data->require_gnome = TRUE;
+  else if (!strncmp (type_name, "Bonobo", 6))
+    requires_data->require_bonobo = TRUE;
+
+  /* Recursively check all children. */
+  gb_widget_children_foreach (widget, (GtkCallback) save_requires_tags_cb,
+			      requires_data);
+}
+
+static void
+save_requires_tags (FILE *fp, GladeProject *project)
+{
+  GladeSaveRequiresData requires_data;
+
+  /* Assume we don't need any of them until we find one of their widgets. */
+  requires_data.require_gnome = FALSE;
+  requires_data.require_gnome_canvas = FALSE;
+  requires_data.require_gnomedb = FALSE;
+  requires_data.require_bonobo = FALSE;
+
+  glade_project_foreach_component (project,
+				   (GtkCallback) save_requires_tags_cb,
+				   &requires_data);
+
+  /* Require "gnome", as provided in libgnomeui/glade/glade-gnome.c. */
+  if (requires_data.require_gnome)
+    fprintf (fp, "<requires lib=\"gnome\"/>\n");
+  /* Require "canvas", as provided in libgnomecanvas/glade/glade-canvas.c. */
+  if (requires_data.require_gnome_canvas)
+    fprintf (fp, "<requires lib=\"canvas\"/>\n");
+  /* Require "gnomedb", as provided in libgnomedb/glade/glade-gnomedb.c. */
+  if (requires_data.require_gnomedb)
+    fprintf (fp, "<requires lib=\"gnomedb\"/>\n");
+  /* Require "bonobo", as provided in libbonoboui/glade/glade-bonobo.c. */
+  if (requires_data.require_bonobo)
+    fprintf (fp, "<requires lib=\"bonobo\"/>\n");
+}
+
 /* This is called when iterating over the components in a project, to output
    each component. It simply calls gb_widget_save() to recursively save the
    XML for the component into the buffer, and it then flushes the buffer to
@@ -267,7 +415,7 @@ save_named_style (const gchar * name,
 void
 save_start_tag (GbWidgetGetArgData * data, const gchar * tag_name)
 {
-  save_indent (data);
+  save_buffer_add_indent (data->buffer, data->indent);
   g_string_append_c (data->buffer, '<');
   g_string_append (data->buffer, tag_name);
   g_string_append (data->buffer, ">\n");
@@ -280,13 +428,70 @@ void
 save_end_tag (GbWidgetGetArgData * data, const gchar * tag_name)
 {
   data->indent--;
-  save_indent (data);
+  save_buffer_add_indent (data->buffer, data->indent);
   g_string_append (data->buffer, "</");
   g_string_append (data->buffer, tag_name);
   g_string_append (data->buffer, ">\n");
 }
 
 
+/* Adds a <widget> start tag to the output buffer, with the given class_name
+   and id, if they are not NULL. */
+void
+save_widget_start_tag (GbWidgetGetArgData * data, const gchar * class_name,
+		       const gchar *id)
+{
+  save_buffer_add_indent (data->buffer, data->indent);
+  g_string_append (data->buffer, "<widget");
+
+  if (class_name)
+    {
+      g_string_append (data->buffer, " class=\"");
+      save_buffer_add_string (data->buffer, class_name);
+      g_string_append_c (data->buffer, '"');
+    }
+
+  if (id)
+    {
+      g_string_append (data->buffer, " id=\"");
+      save_buffer_add_string (data->buffer, id);
+      g_string_append_c (data->buffer, '"');
+    }
+
+  g_string_append (data->buffer, ">\n");
+  data->indent++;
+}
+
+
+/* Adds a <child> start tag to the output buffer, with the given child_name
+   if it is not NULL. */
+void
+save_child_start_tag (GbWidgetGetArgData * data, const gchar * child_name)
+{
+  save_buffer_add_indent (data->buffer, data->indent);
+  g_string_append (data->buffer, "<child");
+
+  if (child_name)
+    {
+      g_string_append (data->buffer, " internal-child=\"");
+      save_buffer_add_string (data->buffer, child_name);
+      g_string_append_c (data->buffer, '"');
+    }
+
+  g_string_append (data->buffer, ">\n");
+  data->indent++;
+}
+
+
+/* Adds a <placeholder/> tag to the output buffer. */
+void
+save_placeholder (GbWidgetGetArgData * data)
+{
+  save_buffer_add_indent (data->buffer, data->indent);
+  g_string_append (data->buffer, "<placeholder/>\n");
+}
+
+
 /* Starts a new line in the output buffer (without indenting). */
 void
 save_newline (GbWidgetGetArgData * data)
@@ -301,9 +506,9 @@ save_newline (GbWidgetGetArgData * data)
    property, e.g. "GtkLabel::justify", so we cut out the first part and output
    <justify>...</justify>. */
 
-void
-save_string (GbWidgetGetArgData * data, const gchar * tag_name,
-	     const gchar * tag_value)
+static void
+save_string_internal (GbWidgetGetArgData * data, const gchar * tag_name,
+		      const gchar * tag_value, gboolean translatable)
 {
   gchar *tag_name_start;
 
@@ -311,14 +516,34 @@ save_string (GbWidgetGetArgData * data, const gchar * tag_name,
     return;
 
   tag_name_start = glade_util_find_start_of_tag_name (tag_name);
-  save_indent (data);
-  g_string_append_c (data->buffer, '<');
-  g_string_append (data->buffer, tag_name_start);
+  save_buffer_add_indent (data->buffer, data->indent);
+
+  g_string_append (data->buffer, "<property");
+
+  if (data->agent)
+    {
+      g_string_append (data->buffer, " agent=\"");
+      save_buffer_add_string (data->buffer, data->agent);
+      g_string_append_c (data->buffer, '"');
+    }
+
+  g_string_append (data->buffer, " name=\"");
+  save_buffer_add_string (data->buffer, tag_name_start);
+  g_string_append_c (data->buffer, '"');
+
+  if (translatable)
+    g_string_append (data->buffer, " translatable=\"yes\"");
+
   g_string_append_c (data->buffer, '>');
   save_buffer_add_string (data->buffer, tag_value);
-  g_string_append (data->buffer, "</");
-  g_string_append (data->buffer, tag_name_start);
-  g_string_append (data->buffer, ">\n");
+  g_string_append (data->buffer, "</property>\n");
+}
+
+void
+save_string (GbWidgetGetArgData * data, const gchar * tag_name,
+	     const gchar * tag_value)
+{
+  save_string_internal (data, tag_name, tag_value, FALSE);
 }
 
 
@@ -326,7 +551,7 @@ void
 save_translatable_string (GbWidgetGetArgData * data, const gchar * tag_name,
 			  const gchar * tag_value)
 {
-  save_string (data, tag_name, tag_value);
+  save_string_internal (data, tag_name, tag_value, TRUE);
   if (data->save_translatable_strings)
     save_add_translatable_string (data, tag_value);
 }
@@ -344,7 +569,7 @@ void
 save_translatable_text (GbWidgetGetArgData * data, const gchar * tag_name,
 			const gchar * tag_value)
 {
-  save_string (data, tag_name, tag_value);
+  save_string_internal (data, tag_name, tag_value, TRUE);
   if (data->save_translatable_strings)
     save_add_translatable_string (data, tag_value);
 }
@@ -358,7 +583,9 @@ save_translatable_text_in_lines (GbWidgetGetArgData * data,
 				 const gchar * tag_name,
 				 const gchar * tag_value)
 {
-  save_string (data, tag_name, tag_value);
+  /* FIXME: This probably won't work if other apps just try to translate the
+     entire string. */
+  save_string_internal (data, tag_name, tag_value, TRUE);
   if (data->save_translatable_strings)
     {
       gchar *items, *pos, *items_end;
@@ -426,17 +653,16 @@ save_combo (GbWidgetGetArgData * data, const gchar * tag_name,
 }
 
 
-/* Colors are currently saved as r,g,b where rgb are 0-255.
-   But we may switch to using RGB:RRRR/GGGG/BBBB so we can use 16-bit values.*/
+/* Colors are now saved as '#rrrrggggbbbb', where rgb are 0-65535.
+   We use gdk_color_parse() when loading, so color names can be used as well.*/
 void
 save_color (GbWidgetGetArgData * data, const gchar * tag_name,
 	    GdkColor * tag_value)
 {
   gchar buf[32];
-  guint16 red = tag_value->red >> 8;
-  guint16 green = tag_value->green >> 8;
-  guint16 blue = tag_value->blue >> 8;
-  sprintf (buf, "%i,%i,%i", red, green, blue);
+
+  sprintf (buf, "#%04x%04x%04x", tag_value->red, tag_value->green,
+	   tag_value->blue);
   save_string (data, tag_name, buf);
 }
 
@@ -457,6 +683,7 @@ save_dialog (GbWidgetGetArgData * data, const gchar * tag_name,
 }
 
 
+/* FIXME: I think this is broken. It should save it relative to the XML file.*/
 void
 save_filename (GbWidgetGetArgData * data, const gchar * tag_name,
 	       const gchar * tag_value)
@@ -491,7 +718,7 @@ save_pixmap_filename (GbWidgetGetArgData * data, const gchar * tag_name,
 	}
       else
 	{
-	  filename = g_basename (tag_value);
+	  filename = (gchar*) g_basename (tag_value);
 	}
 
       save_string (data, tag_name, filename);
@@ -506,28 +733,54 @@ save_font (GbWidgetGetArgData * data, const gchar * tag_name,
   save_string (data, tag_name, tag_value);
 }
 
+
 /* This saves a date in the RFC1123 format (an update of RFC822),
    e.g. 'Sun, 06 Nov 1994 08:49:37 GMT'. */
-void
-save_date (GbWidgetGetArgData * data, const gchar * tag_name,
-	   time_t tag_value)
+static void
+format_date (char *buffer,
+	     time_t tag_value)
 {
   time_t time;
   struct tm *t;
-  gchar buffer[32];
 
   time = tag_value;
   t = gmtime (&time);
   sprintf (buffer, "%s, %02d %s %04d %02d:%02d:%02d GMT",
 	   GladeDayNames[t->tm_wday], t->tm_mday, GladeMonthNames[t->tm_mon],
 	   t->tm_year + 1900, t->tm_hour, t->tm_min, t->tm_sec);
+}
+
+
+/* This saves a date in the RFC1123 format (an update of RFC822),
+   e.g. 'Sun, 06 Nov 1994 08:49:37 GMT'. */
+void
+save_date (GbWidgetGetArgData * data, const gchar * tag_name,
+	   time_t tag_value)
+{
+  gchar buffer[32];
+
+  format_date (buffer, tag_value);
   save_string (data, tag_name, buffer);
 }
 
 
+void
+save_icon (GbWidgetGetArgData * data, const gchar * tag_name,
+	   const gchar * tag_value)
+{
+  /* If it is a stock icon we can save it as an oridnary string.
+     If it isn't, we need to save it as a pixmap filename, i.e. get rid of
+     the path and just save the basename. */
+  if (glade_util_check_is_stock_id (tag_value))
+    save_string (data, tag_name, tag_value);
+  else
+    save_pixmap_filename (data, tag_name, tag_value);
+}
+
+
 /* Adds a string to the output buffer, converting special characters to
    entities, e.g. "<" is output as "&lt;". */
-static void
+void
 save_buffer_add_string (GString * buffer, const gchar * string)
 {
   gchar ch;
@@ -571,19 +824,19 @@ save_buffer_flush (GbWidgetGetArgData * data,
 
 /* Outputs tabs & spaces to indent the line according to the current
    indentation level. Tabs are used to cut down on the file size a bit. */
-static void
-save_indent (GbWidgetGetArgData * data)
+void
+save_buffer_add_indent (GString *buffer, gint indent)
 {
   gint i, ntabs, nspaces;
 
-  ntabs = (data->indent * 2) / 8;
-  nspaces = (data->indent * 2) % 8;
+  ntabs = (indent * 2) / 8;
+  nspaces = (indent * 2) % 8;
 
   for (i = 0; i < ntabs; i++)
-    g_string_append_c (data->buffer, '\t');
+    g_string_append_c (buffer, '\t');
 
   for (i = 0; i < nspaces; i++)
-    g_string_append_c (data->buffer, ' ');
+    g_string_append_c (buffer, ' ');
 }
 
 
@@ -593,7 +846,7 @@ save_indent (GbWidgetGetArgData * data)
 
 /* This adds a translatable string to the buffer, wrapping it in the N_()
    macro so xgettext can find it. */
-static void
+void
 save_add_translatable_string (GbWidgetGetArgData * data,
 			      const gchar * string)
 {
@@ -630,7 +883,7 @@ save_add_translatable_string (GbWidgetGetArgData * data,
 	  g_string_append (buffer, "\\\"");
 	  break;
 	default:
-	  if (isprint (*p))
+	  if (isprint ((unsigned char) *p))
 	    {
 	      g_string_append_c (buffer, *p);
 	    }
@@ -676,3 +929,79 @@ save_translatable_strings (GbWidgetGetArgData * data)
 
   fclose (fp);
 }
+
+
+void
+save_signal		(GbWidgetGetArgData	*data,
+			 gchar			*signal_name,
+			 gchar			*handler,
+			 gboolean		 after,
+			 gchar			*object,
+			 time_t			 last_modification_time)
+{
+  /* Don't save signals without names or handlers. */
+  if (!signal_name || !signal_name[0] || ! handler || !handler[0])
+    return;
+
+  save_buffer_add_indent (data->buffer, data->indent);
+  g_string_append (data->buffer, "<signal name=\"");
+  save_buffer_add_string (data->buffer, signal_name);
+  g_string_append (data->buffer, "\" handler=\"");
+  save_buffer_add_string (data->buffer, handler);
+  g_string_append (data->buffer, "\"");
+
+  if (after)
+    g_string_append (data->buffer, " after=\"yes\"");
+
+  if (object)
+    {
+      g_string_append (data->buffer, " object=\"");
+      save_buffer_add_string (data->buffer, object);
+      g_string_append (data->buffer, "\"");
+    }
+
+  if (last_modification_time != 0)
+    {
+      gchar buffer[32];
+
+      format_date (buffer, last_modification_time);
+
+      g_string_append (data->buffer, " last_modification_time=\"");
+      save_buffer_add_string (data->buffer, buffer);
+      g_string_append (data->buffer, "\"");
+    }
+
+  g_string_append (data->buffer, "/>\n");
+}
+
+
+void
+save_accelerator	(GbWidgetGetArgData	*data,
+			 guint8			 modifiers,
+			 gchar			*key,
+			 gchar			*signal)
+{
+  gchar *modifiers_string;
+
+  /* Don't save accelerators without signals or keys. */
+  if (!key || !key[0] || !signal || !signal[0])
+    return;
+
+  save_buffer_add_indent (data->buffer, data->indent);
+  g_string_append (data->buffer, "<accelerator key=\"");
+  save_buffer_add_string (data->buffer, key);
+  g_string_append (data->buffer, "\"");
+
+  modifiers_string = glade_util_create_modifiers_string (modifiers);
+  g_string_append (data->buffer, " modifiers=\"");
+  save_buffer_add_string (data->buffer, modifiers_string);
+  g_string_append (data->buffer, "\"");
+
+  g_string_append (data->buffer, " signal=\"");
+  save_buffer_add_string (data->buffer, signal);
+  g_string_append (data->buffer, "\"");
+
+  g_string_append (data->buffer, "/>\n");
+}
+
+
