@@ -40,6 +40,11 @@
 #include "source_os2.h"
 #endif
 
+/* Turn this on to add -DG_DISABLE_DEPRECATED etc. flags in generated code,
+   so we can check if Glade is generating any deprecated code. */
+#if 0
+#define GLADE_ADD_DISABLE_DEPRECATED_FLAGS
+#endif
 
 /* An internal struct to pass data to the source_write_component() callback. */
 typedef struct _GladeSourceCallbackData GladeSourceCallbackData;
@@ -85,9 +90,9 @@ static void source_write_component_create (GtkWidget * component,
 					   GbWidgetWriteSourceData * data);
 
 static void source_write_build_files (GbWidgetWriteSourceData * data);
+static void source_write_autogen_sh (GbWidgetWriteSourceData * data);
 
 static void source_write_gtk_build_files (GbWidgetWriteSourceData * data);
-static void source_write_gtk_autogen_sh (GbWidgetWriteSourceData * data);
 static void source_write_gtk_configure_in (GbWidgetWriteSourceData * data);
 static void source_write_gtk_makefile_am (GbWidgetWriteSourceData * data);
 static void source_write_gtk_makefile_am_pixmaps_targets (GbWidgetWriteSourceData * data,
@@ -95,7 +100,6 @@ static void source_write_gtk_makefile_am_pixmaps_targets (GbWidgetWriteSourceDat
 							  FILE                    * fp);
 
 static void source_write_gnome_build_files (GbWidgetWriteSourceData * data);
-static void source_write_gnome_autogen_sh (GbWidgetWriteSourceData * data);
 static void source_write_gnome_configure_in (GbWidgetWriteSourceData * data);
 static void source_write_gnome_makefile_am (GbWidgetWriteSourceData * data);
 static void source_write_gnome_makefile_am_pixmaps_targets (GbWidgetWriteSourceData * data,
@@ -687,12 +691,12 @@ source_write_interface_c_preamble (GbWidgetWriteSourceData * data, FILE *fp)
 
   fprintf (fp,
 	   "#define GLADE_HOOKUP_OBJECT(component,widget,name) \\\n"
-	   "  gtk_object_set_data_full (GTK_OBJECT (component), name, \\\n"
-	   "    gtk_widget_ref (widget), (GtkDestroyNotify) gtk_widget_unref)\n\n");
+	   "  g_object_set_data_full (G_OBJECT (component), name, \\\n"
+	   "    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)\n\n");
 
   fprintf (fp,
 	   "#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \\\n"
-	   "  gtk_object_set_data (GTK_OBJECT (component), name, widget)\n\n");
+	   "  g_object_set_data (G_OBJECT (component), name, widget)\n\n");
 }
 
 
@@ -708,6 +712,9 @@ source_write_callback_h_preamble (GbWidgetWriteSourceData * data, FILE *fp)
     fprintf (fp, "#include <gnome.h>\n\n");
   else
     fprintf (fp, "#include <gtk/gtk.h>\n\n");
+
+  if (glade_project_get_gnome_db_support (data->project))
+    fprintf (fp, "#include <libgnomedb/libgnomedb.h>\n");
 }
 
 
@@ -812,10 +819,10 @@ source_write_main_c (GbWidgetWriteSourceData * data)
   source_write_preamble (data->project_name, fp);
 
   fprintf (fp,
-	   _("/*\n"
-	     " * Initial main.c file generated by Glade. Edit as required.\n"
-	     " * Glade will not overwrite this file.\n"
-	     " */\n\n"));
+	   "/*\n"
+	   " * Initial main.c file generated by Glade. Edit as required.\n"
+	   " * Glade will not overwrite this file.\n"
+	   " */\n\n");
 
   fprintf (fp,
 	   "#ifdef HAVE_CONFIG_H\n"
@@ -962,7 +969,7 @@ source_write_build_files (GbWidgetWriteSourceData * data)
 static void
 source_write_gtk_build_files (GbWidgetWriteSourceData * data)
 {
-  source_write_gtk_autogen_sh (data);
+  source_write_autogen_sh (data);
   if (data->error)
     return;
 
@@ -977,7 +984,7 @@ source_write_gtk_build_files (GbWidgetWriteSourceData * data)
 /* Copies the generic autogen.sh script which runs aclocal, automake
    & autoconf to create the Makefiles etc. */
 static void
-source_write_gtk_autogen_sh (GbWidgetWriteSourceData * data)
+source_write_autogen_sh (GbWidgetWriteSourceData * data)
 {
   static const gchar *data_dir = GLADE_DATADIR "/glade-2";
   gchar *project_dir, *srcbuffer, *destbuffer;
@@ -1055,7 +1062,7 @@ source_write_gtk_configure_in (GbWidgetWriteSourceData * data)
 	   data->program_name);
 
   fprintf (fp,
-	   "pkg_modules=\"gtk+-2.0 >= 1.3.13\"\n"
+	   "pkg_modules=\"gtk+-2.0 >= 2.0.0\"\n"
 	   "PKG_CHECK_MODULES(PACKAGE, [$pkg_modules])\n"
 	   "AC_SUBST(PACKAGE_CFLAGS)\n"
 	   "AC_SUBST(PACKAGE_LIBS)\n"
@@ -1075,19 +1082,6 @@ source_write_gtk_configure_in (GbWidgetWriteSourceData * data)
 	       "\n");
     }
 
-  /* Set -Wall when using gcc, since it helps catch a lot of mistakes. */
-  fprintf (fp,
-	   "dnl Use -Wall if we have gcc.\n"
-	   "changequote(,)dnl\n"
-	   "if test \"x$GCC\" = \"xyes\"; then\n"
-	   "  case \" $CFLAGS \" in\n"
-	   "  *[\\ \\\t]-Wall[\\ \\\t]*) ;;\n"
-	   "  *) CFLAGS=\"$CFLAGS -Wall\" ;;\n"
-	   "  esac\n"
-	   "fi\n"
-	   "changequote([,])dnl\n"
-	   "\n");
-
   fprintf (fp,
 	   "AC_OUTPUT([\n"
 	   "Makefile\n");
@@ -1162,6 +1156,11 @@ source_write_gtk_makefile_am (GbWidgetWriteSourceData * data)
 	   "INCLUDES = \\\n"
 	   "\t-DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n"
 	   "\t-DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n"
+#ifdef GLADE_ADD_DISABLE_DEPRECATED_FLAGS
+	   "\t-DG_DISABLE_DEPRECATED \\\n"
+	   "\t-DGDK_DISABLE_DEPRECATED \\\n"
+	   "\t-DGTK_DISABLE_DEPRECATED \\\n"
+#endif
 	   "\t@PACKAGE_CFLAGS@\n"
 	   "\n");
 
@@ -1198,13 +1197,12 @@ source_write_gtk_makefile_am (GbWidgetWriteSourceData * data)
   fprintf (fp,
 	   "%s_LDADD = @PACKAGE_LIBS@",
 	   program_name_as_target);
-#if 0
-  /* I don't think we need this now that we use AM_GLIB_GNU_GETTEXT. */
+
   if (glade_project_get_gettext_support (data->project))
     {
       fprintf (fp, " $(INTLLIBS)");
     }
-#endif
+
   fprintf (fp, "\n\n");
 
   if (is_toplevel)
@@ -1288,7 +1286,7 @@ source_write_gtk_makefile_am_pixmaps_targets (GbWidgetWriteSourceData * data,
 static void
 source_write_gnome_build_files (GbWidgetWriteSourceData * data)
 {
-  source_write_gnome_autogen_sh (data);
+  source_write_autogen_sh (data);
   if (data->error)
     return;
 
@@ -1302,65 +1300,6 @@ source_write_gnome_build_files (GbWidgetWriteSourceData * data)
 }
 
 
-static void
-source_write_gnome_autogen_sh (GbWidgetWriteSourceData * data)
-{
-  FILE *fp;
-  gint old_umask;
-  gchar *filename;
-
-  filename = glade_util_make_absolute_path (glade_project_get_directory (data->project), "autogen.sh");
-
-  /* FIXME: If autogen.sh exists, just leave it, for now. */
-  if (glade_util_file_exists (filename))
-    {
-      g_free (filename);
-      return;
-    }
-
-  fp = fopen (filename, "w");
-  if (fp == NULL)
-    {
-      data->error = glade_error_new_system (_("Couldn't create file:\n  %s\n"),
-					    filename);
-      g_free (filename);
-      return;
-    }
-
-  fprintf (fp,
-	   "#!/bin/sh\n"
-	   "# Run this to generate all the initial makefiles, etc.\n"
-	   "\n"
-	   "srcdir=`dirname $0`\n"
-	   "test -z \"$srcdir\" && srcdir=.\n"
-	   "\n"
-	   "PKG_NAME=\"the package.\"\n"
-	   "\n"
-	   "(test -f $srcdir/configure.in) || {\n"
-	   "    echo -n \"**Error**: Directory \"\\`$srcdir\\'\" does not look like the\"\n"
-	   "    echo \" top-level directory\"\n"
-	   "    exit 1\n"
-	   "}\n"
-	   "\n"
-	   "which gnome-autogen.sh || {\n"
-	   "    echo \"You need to install gnome-common from the GNOME CVS\"\n"
-	   "    exit 1\n"
-	   "}\n"
-	   "USE_GNOME2_MACROS=1 . gnome-autogen.sh\n");
-
-  fclose (fp);
-
-#ifndef _WIN32
-  /* We need to make the script executable, but we try to honour any umask. */
-  old_umask = umask (0666);
-  chmod (filename, 0777 & ~old_umask);
-  umask (old_umask);
-#endif
-
-  g_free (filename);
-}
-
-
 static void
 source_write_gnome_configure_in (GbWidgetWriteSourceData * data)
 {
@@ -1371,7 +1310,8 @@ source_write_gnome_configure_in (GbWidgetWriteSourceData * data)
   alt_filename = glade_util_make_absolute_path (glade_project_get_directory (data->project), "configure.ac");
 
   /* FIXME: If configure.in exists, just leave it, for now. */
-  if (glade_util_file_exists (filename))
+  if (glade_util_file_exists (filename)
+      || glade_util_file_exists (alt_filename))
     {
       g_free (filename);
       g_free (alt_filename);
@@ -1403,8 +1343,6 @@ source_write_gnome_configure_in (GbWidgetWriteSourceData * data)
 	   "AC_PROG_CC\n"
 	   "AM_PROG_CC_STDC\n"
 	   "AC_HEADER_STDC\n"
-	   "\n"
-	   "GNOME_COMPILE_WARNINGS\n"
 	   "\n",
 	   data->program_name);
 
@@ -1503,6 +1441,12 @@ source_write_gnome_makefile_am (GbWidgetWriteSourceData * data)
 	   "INCLUDES = \\\n"
 	   "\t-DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n"
 	   "\t-DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n"
+#ifdef GLADE_ADD_DISABLE_DEPRECATED_FLAGS
+	   "\t-DG_DISABLE_DEPRECATED \\\n"
+	   "\t-DGDK_DISABLE_DEPRECATED \\\n"
+	   "\t-DGTK_DISABLE_DEPRECATED \\\n"
+	   "\t-DGNOME_DISABLE_DEPRECATED \\\n"
+#endif
 	   "\t@PACKAGE_CFLAGS@\n"
 	   "\n");
 
@@ -1539,13 +1483,12 @@ source_write_gnome_makefile_am (GbWidgetWriteSourceData * data)
   fprintf (fp,
 	   "%s_LDADD = @PACKAGE_LIBS@",
 	   program_name_as_target);
-#if 0
-  /* I don't think we need this now that we use AM_GLIB_GNU_GETTEXT. */
+
   if (glade_project_get_gettext_support (data->project))
     {
       fprintf (fp, " $(INTLLIBS)");
     }
-#endif
+
   fprintf (fp, "\n\n");
 
   if (is_toplevel)
@@ -2094,14 +2037,14 @@ source_write_support_files (GbWidgetWriteSourceData * data)
 	       "      else\n"
 	       "        parent = widget->parent;\n"
 	       "      if (!parent)\n"
-	       "        parent = gtk_object_get_data (GTK_OBJECT (widget), \"GladeParentKey\");\n"
+	       "        parent = g_object_get_data (G_OBJECT (widget), \"GladeParentKey\");\n"
 	       "      if (parent == NULL)\n"
 	       "        break;\n"
 	       "      widget = parent;\n"
 	       "    }\n"
 	       "\n"
-	       "  found_widget = (GtkWidget*) gtk_object_get_data (GTK_OBJECT (widget),\n"
-	       "                                                   widget_name);\n"
+	       "  found_widget = (GtkWidget*) g_object_get_data (G_OBJECT (widget),\n"
+	       "                                                 widget_name);\n"
 	       "  if (!found_widget)\n"
 	       "    g_warning (\"Widget not found: %%s\", widget_name);\n"
 	       "  return found_widget;\n"
@@ -2790,7 +2733,9 @@ source_write_no_editing_warning (FILE *fp)
 {
   /*
    * Output a 3-line comment like this one, makes it easy for translators.
+   * Actually I've turned translation off now, as UTF-8 may cause problems
+   * in the C code. See bug #95435.
    */
   fprintf (fp, "/*\n * %s\n */\n\n",
-	   _("DO NOT EDIT THIS FILE - it is generated by Glade."));
+	   "DO NOT EDIT THIS FILE - it is generated by Glade.");
 }
