@@ -74,6 +74,8 @@ tree_init ()
   gtk_window_set_title (GTK_WINDOW (win_tree), _ ("Widget Tree"));
   gtk_container_set_border_width (GTK_CONTAINER (win_tree), 0);
   gtk_window_set_wmclass (GTK_WINDOW (win_tree), "widget_tree", "Glade");
+  gtk_window_add_accel_group (GTK_WINDOW (win_tree),
+			      glade_get_global_accel_group ());
 
   scrolled_win = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
@@ -108,8 +110,8 @@ tree_init ()
   gtk_tree_view_column_set_resizable (col, TRUE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (widget_tree), col);
 
-  gtk_signal_connect_after (GTK_OBJECT (widget_tree), "button_press_event",
-			    GTK_SIGNAL_FUNC (tree_on_button_press), NULL);
+  gtk_signal_connect (GTK_OBJECT (widget_tree), "button_press_event",
+		      GTK_SIGNAL_FUNC (tree_on_button_press), NULL);
   g_signal_connect (G_OBJECT (tree_selection), "changed",
 		    GTK_SIGNAL_FUNC (tree_on_selection_changed), NULL);
 }
@@ -164,14 +166,19 @@ tree_add_widget (GtkWidget * widget)
 	      parent_iter = &tmp_iter;
 	    }
 
+	  /* Create the pixbuf for the icon, if necessary. */
+	  if (gbwidget->pixbuf == NULL && gbwidget->pixmap_struct)
+	    {
+	      gbwidget->pixbuf = gdk_pixbuf_new_from_xpm_data (gbwidget->pixmap_struct);
+	    }
+
 	  gtk_tree_store_append (tree_store, &iter, parent_iter);
 	  gtk_tree_store_set (tree_store, &iter,
+			      COLUMN_ICON, gbwidget->pixbuf,
 			      COLUMN_TEXT, gtk_widget_get_name (widget),
 			      COLUMN_OBJECT, widget,
 			      -1);
 
-	  /* FIXME: Set icon. */
-
 	  /* Save a pointer to the GNode inside the widget. */
 	  gtk_object_set_data (GTK_OBJECT (widget), GLADE_TREE_NODE_KEY,
 			       iter.user_data);
@@ -421,33 +428,40 @@ tree_on_selection_changed (GtkTreeSelection *selection, gpointer data)
 }
 
 
-/* This is called when a button is pressed in the CTree. If it was the
+/* This is called when a button is pressed in the tree. If it was the
    right mouse button we show the popup menu for the widget. */
 static gint
 tree_on_button_press (GtkWidget      *tree,
 		      GdkEventButton *event,
 		      gpointer        data)
 {
-  /* FIXME: Finish. */
-#if 0
-  GtkCTreeNode *node;
-  GtkWidget *widget;
-  gint row, col;
+  GtkTreePath *path;
+  GtkTreeIter iter;
 
-  /* TODO: change to own menu */
-  if (event->button == 3)
+  if (event->button != 3
+      || event->window != gtk_tree_view_get_bin_window (GTK_TREE_VIEW (tree)))
+    return FALSE;
+
+  if (!gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (tree),
+				      event->x, event->y,
+				      &path, NULL, NULL, NULL))
+    return FALSE;
+
+  if (gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path))
     {
-      gtk_clist_get_selection_info (GTK_CLIST (ctree), event->x, event->y,
-				    &row, &col);
-      node = GTK_CTREE_NODE (g_list_nth (GTK_CLIST (ctree)->row_list, row));
-      if (node == NULL)
-	return FALSE;
+      GtkWidget *widget;
 
-      widget = GTK_WIDGET (gtk_ctree_node_get_row_data (ctree, node));
-      gb_widget_show_popup_menu (GTK_WIDGET (widget), event);
-      return TRUE;
+      gtk_tree_model_get (GTK_TREE_MODEL (tree_store), &iter,
+			  COLUMN_OBJECT, &widget,
+			  -1);
+
+      if (widget)
+	gb_widget_show_popup_menu (GTK_WIDGET (widget), event);
+
+      gtk_tree_path_free (path);
     }
-#endif
-  return FALSE;
+
+  return TRUE;
 }
 
+
