@@ -1930,7 +1930,7 @@ glade_util_gtk_combo_func (gpointer data)
       label = GTK_BIN (listitem)->child;
       if (!label || !GTK_IS_LABEL (label))
 	return NULL;
-      gtk_label_get (GTK_LABEL (label), &ltext);
+      ltext = (gchar*) gtk_label_get_text (GTK_LABEL (label));
     }
   return ltext;
 }
